# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/confession/confession/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/confession/confession/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Confession\\Confession\\": "packages/confession/confession/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Confession\Confession\Providers\ConfessionServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Confession'  => Confession\Confession\Facades\Confession::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Confession\\ConfessionTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Confession\Confession\Providers\ConfessionServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Confession\Confession\Providers\ConfessionServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Confession\Confession\Providers\ConfessionServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/confession/{modulename}

**User**

    http://path-to-route-folder/user/confession/{modulename}

**Public**

    http://path-to-route-folder/confessions


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/confession/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/confession/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/confession/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/confession/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/confession/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/confession/{modulename}/{slug}
    METHOD: GET